==> zio-aws-rekognition_2.12-5.17.123.1-sources.jar: zio/aws/rekognition/model/GetTextDetectionRequest.scala <==
package zio.aws.rekognition.model
import java.lang.Integer
import zio.aws.rekognition.model.primitives.{PaginationToken, MaxResults, JobId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetTextDetectionRequest(
    jobId: JobId,
    maxResults: Option[MaxResults] = None,
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest = {
    import GetTextDetectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest
      .builder()
      .jobId(JobId.unwrap(jobId): java.lang.String)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.GetTextDetectionRequest.ReadOnly =
    zio.aws.rekognition.model.GetTextDetectionRequest.wrap(buildAwsValue())
}
object GetTextDetectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.GetTextDetectionRequest =
      zio.aws.rekognition.model.GetTextDetectionRequest(
        jobId,
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def jobId: JobId
    def maxResults: Option[MaxResults]
    def nextToken: Option[PaginationToken]
    def getJobId: ZIO[Any, Nothing, JobId] = ZIO.succeed(jobId)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest
  ) extends zio.aws.rekognition.model.GetTextDetectionRequest.ReadOnly {
    override val jobId: JobId =
      zio.aws.rekognition.model.primitives.JobId(impl.jobId())
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.rekognition.model.primitives.MaxResults(value))
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.rekognition.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest
  ): zio.aws.rekognition.model.GetTextDetectionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-rekognition_2.12-5.17.195.1-sources.jar: zio/aws/rekognition/model/GetTextDetectionRequest.scala <==
package zio.aws.rekognition.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.rekognition.model.primitives.{PaginationToken, MaxResults, JobId}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GetTextDetectionRequest(
    jobId: JobId,
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest = {
    import GetTextDetectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest
      .builder()
      .jobId(JobId.unwrap(jobId): java.lang.String)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.GetTextDetectionRequest.ReadOnly =
    zio.aws.rekognition.model.GetTextDetectionRequest.wrap(buildAwsValue())
}
object GetTextDetectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.GetTextDetectionRequest =
      zio.aws.rekognition.model.GetTextDetectionRequest(
        jobId,
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def jobId: JobId
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[PaginationToken]
    def getJobId: ZIO[Any, Nothing, JobId] = ZIO.succeed(jobId)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest
  ) extends zio.aws.rekognition.model.GetTextDetectionRequest.ReadOnly {
    override val jobId: JobId =
      zio.aws.rekognition.model.primitives.JobId(impl.jobId())
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.rekognition.model.primitives.MaxResults(value))
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.rekognition.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.GetTextDetectionRequest
  ): zio.aws.rekognition.model.GetTextDetectionRequest.ReadOnly = new Wrapper(
    impl
  )
}
